@@ -1,15 +1,49 @@
 use strict;
 use warnings;
 package Parse::IRCLog;
-{
-  $Parse::IRCLog::VERSION = '1.105';
-}
 # ABSTRACT: parse internet relay chat logs
-
+$Parse::IRCLog::VERSION = '1.106';
 use Carp ();
 use Parse::IRCLog::Result;
 use Symbol ();
 
+# =head1 SYNOPSIS
+#
+#   use Parse::IRCLog;
+#
+#   $result = Parse::IRCLog->parse("perl-2004-02-01.log");
+#
+#   my %to_print = ( msg => 1, action => 1 );
+#
+#   for ($result->events) {
+#     next unless $to_print{ $_->{type} };
+#     print "$_->{nick}: $_->{text}\n";
+#   }
+#
+# =head1 DESCRIPTION
+#
+# This module provides a simple framework to parse IRC logs in arbitrary formats.
+#
+# A parser has a set of regular expressions for matching different events that
+# occur in an IRC log, such as "msg" and "action" events.  Each line in the log
+# is matched against these rules and a result object, representing the event
+# stream, is returned.
+#
+# The rule set, described in greated detail below, can be customized by
+# subclassing Parse::IRCLog.  In this way, Parse::IRCLog can provide a generic
+# interface for log analysis across many log formats, including custom formats.
+#
+# Normally, the C<parse> method is used to create a result set without storing a
+# parser object, but a parser may be created and reused.
+#
+# =method new
+#
+# This method constructs a new parser (with C<< $class->construct >>) and
+# initializes it (with C<< $obj->init >>).  Construction and initialization are
+# separated for ease of subclassing initialization for future pipe dreams like
+# guessing what ruleset to use.
+#
+# =cut
 
 sub new {
   my $class = shift;
@@ -18,9 +52,20 @@ sub new {
   $class->construct->init;
 }
 
+# =method construct
+#
+# The parser constructor just returns a new, empty parser object.  It should be a
+# blessed hashref.
+#
+# =cut
 
 sub construct { bless {} => shift; }
 
+# =method init
+#
+# The initialization method configures the object, loading its ruleset.
+#
+# =cut
 
 sub init {
   my $self = shift;
@@ -28,9 +73,40 @@ sub init {
   $self;
 }
 
+# =method patterns
+#
+# This method returns a reference to a hash of regular expressions, which are
+# used to parse the logs.  Only a few, so far, are required by the parser,
+# although internally a few more are used to break down the task of parsing
+# lines.
+#
+# C<action> matches an action; that is, the result of /ME in IRC.  It should
+# return the following matches:
+#
+#  $1 - timestamp
+#  $2 - nick prefix
+#  $3 - nick
+#  $4 - the action
+#
+# C<msg> matches a message; that is, the result of /MSG (or "normal talking") in
+# IRC.  It should return the following matches:
+#
+#  $1 - timestamp
+#  $2 - nick prefix
+#  $3 - nick
+#  $3 - channel
+#  $5 - the action
+#
+# Read the source for a better idea as to how these regexps break down.  Oh, and
+# for what it's worth, the default patterns are based on my boring, default irssi
+# configuration.  Expect more rulesets to be included in future distributions.
+#
+# =cut
 
 sub patterns {
-  return $_[0]{patterns} if ref $_[0] and defined $_[0]{patterns};
+  my ($self) = @_;
+
+  return $self->{patterns} if ref $self and defined $self->{patterns};
 
   my $p;
 
@@ -89,9 +165,20 @@ sub patterns {
     (.+)
   /x;
 
+  $self->{patterns} = $p if ref $self;
   $p;
 }
 
+# =method parse
+#
+#   my $result = $parser->parse($file)
+#
+# This method parses the file named and returns a Parse::IRCLog::Result object
+# representing the results.  The C<parse> method can be called on a parser object
+# or on the class.  If called on the class, a parser will be instantiated for the
+# method call and discarded when C<parse> returns.
+#
+# =cut
 
 sub parse {
   my $self = shift;
@@ -105,6 +192,18 @@ sub parse {
   Parse::IRCLog::Result->new(@events);
 }
 
+# =method parse_line
+#
+#   my $info = $parser->parse_line($line);
+#
+# This method is used internally by C<parse> to turn each line into an event.
+# While it could someday be made slick, it's adequate for now.  It attempts to
+# match each line against the required patterns from the C<patterns> result and
+# if successful returns a hashref describing the event.
+#
+# If no match can be found, an "unknown" event is returned.
+#
+# =cut
 
 sub parse_line {
   my ($self, $line) = @_;
@@ -117,6 +216,18 @@ sub parse_line {
   return { type => 'unknown', text => $line };
 }
 
+# =head1 TODO
+#
+# Write a few example subclasses for common log formats.
+#
+# Add a few more default event types: join, part, nick.  Others?
+#
+# Possibly make the C<patterns> sub an module, to allow subclassing to override
+# only one or two patterns.  For example, to use the default C<nick> pattern but
+# override the C<nick_container> or C<action_leader>.  This sounds like a very
+# good idea, actually, now that I write it down.
+#
+# =cut
 
 1;
 
@@ -124,13 +235,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Parse::IRCLog - parse internet relay chat logs
 
 =head1 VERSION
 
-version 1.105
+version 1.106
 
 =head1 SYNOPSIS
 
